@@ -82,6 +82,8 @@ class MYSQLExporter(Result):
         try:
             if self.args.get_only_ff:
                 args=[args[0], args[1]]
+                print args
+            print(query %tuple(args))
             self.sqlconn.cursor().execute(query %tuple(args))
             self.sqlconn.commit()
 
